package com.qianhe.service;

import com.qianhe.domain.SjGfjsKhwt;
import com.qianhe.domain.SjGfjsKhwtCb;

import java.util.List;

/**
 * 规范建设-考核问题 原否决项标准Service接口
 * 
 * @author qianhe
 * @date 2024-07-22
 */
public interface ISjGfjsKhwtService
{
    /**
     * 查询规范建设-考核问题 原否决项标准
     * 
     * @param id 规范建设-考核问题 原否决项标准主键
     * @return 规范建设-考核问题 原否决项标准
     */
    public SjGfjsKhwt selectSjGfjsKhwtById(Long id);

    /**
     * 查询规范建设-考核问题 原否决项标准列表
     * 
     * @param sjGfjsKhwt 规范建设-考核问题 原否决项标准
     * @return 规范建设-考核问题 原否决项标准集合
     */
    public List<SjGfjsKhwt> selectSjGfjsKhwtList(SjGfjsKhwt sjGfjsKhwt);

    /**
     * 新增规范建设-考核问题 原否决项标准
     * 
     * @param sjGfjsKhwt 规范建设-考核问题 原否决项标准
     * @return 结果
     */
    public int insertSjGfjsKhwt(SjGfjsKhwt sjGfjsKhwt);

    /**
     * 修改规范建设-考核问题 原否决项标准
     * 
     * @param sjGfjsKhwt 规范建设-考核问题 原否决项标准
     * @return 结果
     */
    public int updateSjGfjsKhwt(SjGfjsKhwt sjGfjsKhwt);

    /**
     * 批量删除规范建设-考核问题 原否决项标准
     * 
     * @param ids 需要删除的规范建设-考核问题 原否决项标准主键集合
     * @return 结果
     */
    public int deleteSjGfjsKhwtByIds(Long[] ids);

    /**
     * 删除规范建设-考核问题 原否决项标准信息
     * 
     * @param id 规范建设-考核问题 原否决项标准主键
     * @return 结果
     */
    public int deleteSjGfjsKhwtById(Long id);

    List<SjGfjsKhwt> selectSjGfjsKhwtCxList(SjGfjsKhwt sjGfjsKhwt);

    List<String> getFlmcList(SjGfjsKhwtCb cb);


    List<SjGfjsKhwtCb> getPjbzList(SjGfjsKhwtCb cb);


}
